@@ -4,8 +4,8 @@ use serde_yaml::Value;
 use std::collections::BTreeMap;
 
 // Create clap subcommand arguments
-pub fn make_subcommand<'a>() -> App<'a> {
-    App::new("compare")
+pub fn make_subcommand<'a>() -> Command<'a> {
+    Command::new("compare")
         .about("Compare 1 YAML file against others")
         .after_help("Only the *first* file can contain multiple sets of runlists")
         .arg(
